@@ -18,7 +18,7 @@ def add_watermark() -> None:
 # 给pdf加水印-有参数
 # @except_dec()
 @instruction
-def add_watermark_by_parameters(pdf_file, mark_str, output_file_name='添加了水印的文件.pdf') -> None:
+def add_watermark_by_parameters(pdf_file, mark_str, output_path=None, output_file_name=None) -> None:
     """
     必填参数：
     pdf_file:pdf的位置，例如：d:/code/程序员晚枫.pdf
@@ -26,7 +26,7 @@ def add_watermark_by_parameters(pdf_file, mark_str, output_file_name='添加了
     选填参数：
     output_file_name：指定添加了水印的文件名称，可以不指定，默认是：添加了水印的文件.pdf
     """
-    popdf.add_watermark_by_parameters(pdf_file, mark_str, output_file_name)
+    popdf.add_watermark_by_parameters(pdf_file, mark_str, output_path, output_file_name)
 
 
 # txt转pdf
@@ -39,8 +39,8 @@ def txt2pdf(path: str, res_pdf='txt2pdf.pdf'):
 # PDF加密
 # @except_dec()
 @instruction
-def encrypt4pdf(path, password, res_pdf='encrypt.pdf'):
-    popdf.encrypt4pdf(path, password, res_pdf)
+def encrypt4pdf(path, password, output_path=None):
+    popdf.encrypt4pdf(path, password, output_path)
 
 
 # PDF解密
